// ====================
// = Global Functions =
// ====================
function closeAllApps(){ // makes sure that no app is left open (is triggered during page turns)
	stopBoxing();
}
$('#showcase-spin').toggle(function(){ // toggles a "showcase spin" of the whole book
	$('#book').addClass('showcase');
},function(){
	$('#book').removeClass('showcase');
});

// ================
// = Page Turning =
// ================
function nextPage(){
	closeAllApps();
	$('#book section:not(.flipped):first,#book section:nth-child(even):not(.flipped):first').addClass('flip').animate({opacity:'+=0'},2000,function(){
		$(this).removeClass('flip').addClass('flipped');
		if($('#book section:not(.flipped)').size() == '0'){ // Hide page controler if it has reached the end
			$('#next').hide('slow');
		}
		$('#prev').show('slow'); // Show page controller, because it can't be at the end
	});
	return false;
}
function prevPage(){
	closeAllApps();
	$('#book section.flipped:last,#book section:nth-child(odd).flipped:last').addClass('reverse-flip').animate({opacity:'+=0'},600,function(){
		$(this).removeClass('flipped').removeClass('reverse-flip');
		if($('#book section.flipped').size() == '0'){ // Hide page controler if it has reached the end
			$('#prev').hide('slow');
		}
		$('#next').show('slow'); // Show page controller, because it can't be at the end
	});
	return false;
}
$(document).keydown(function(event){
	if(event.keyCode == '39'){ // right arrow
		nextPage();
	}
	if(event.keyCode == '37'){ // left arrow
		prevPage();
	}
});
$('#next').click(function(){
	nextPage();
});
$('#prev').click(function(){
	prevPage();
});


// ===========
// = 3d Book =
// ===========
is3d = false; // original state is 2d
function perspectiveShift(result){
	if(result == '3d'){ // if desired perspective is 3d
		is3d = false;
	}
	if(result == '2d'){ // if desired perspective is 2d
		is3d = true;
	}
	if(is3d != true){ // if it's 2d
		$('#book').addClass('threeDify').animate({opacity:'+=0'},2000,function(){
			$(this).removeClass('threeDify').removeClass('twoD').addClass('threeD');
		});
		is3d = true;
	}else{ // if it's 3d
		$('#book').addClass('twoDify').animate({opacity:'+=0'},600,function(){
			$(this).removeClass('twoDify').removeClass('threeD').addClass('twoD');
		});
		is3d = false;
	}
}
$(document).keydown(function(event){
	if(event.keyCode == '51'){ // "3" key
		perspectiveShift();
	}
});


// ===============
// = Boxing Game =
// ===============
function startBoxing(){
	var boxingRedScore = 0;
	var boxingBlueScore = 0;
	$('#boxing-scorecard .red').html(boxingRedScore);
	$('#boxing-scorecard .blue').html(boxingBlueScore);

	$('#launch-boxing-game').html('Exit Game');
	perspectiveShift('3d');
	$('#boxing-game').addClass('start').animate({opacity:'+=0'},1000,function(){
		$(this).removeClass('start').addClass('playing');
	});
	$('#boxing-scorecard').slideDown('slow');
	$('#boxing-instructions').fadeIn('slow');

	$(document).keydown(function(event){
		if(event.keyCode == '87'){ // "w" key
			$('#boxer-red .arm-right').addClass('punch').animate({opacity:'+=0'},200,function(){
				// *NEED TO GET THE POINTS TO GET COUNTED HERE
				$('#boxer-blue .head').css('opacity','1').animate({opacity:'0.5'},100);
			}).animate({opacity:'+=0'},200,function(){
				$(this).removeClass('punch');
			});
			var redBoxerPunch = true;
		}
		if(event.keyCode == '79'){ // "o" key
			$('#boxer-blue .arm-left').addClass('punch').animate({opacity:'+=0'},200,function(){
				// *NEED TO GET THE POINTS TO GET COUNTED HERE
				$('#boxer-red .head').css('opacity','1').animate({opacity:'0.5'},100);
			}).animate({opacity:'+=0'},200,function(){
				$(this).removeClass('punch');
			});
			var blueBoxerPunch = true;
		}
		if(event.keyCode == '81'){ // "q" key
			var redBoxerBlock = true;
		}
		if(event.keyCode == '80'){ // "p" key
			var blueBoxerBlock = true;
		}
		if(redBoxerPunch == true && blueBoxerBlock != true){
			boxingRedScore++;
		}
		if(blueBoxerPunch == true && redBoxerBlock != true){
			boxingBlueScore++;
		}
		$('#boxing-scorecard .red').html(boxingRedScore);
		$('#boxing-scorecard .blue').html(boxingBlueScore);
	});
	return false;
}
function stopBoxing(){
	$('#launch-boxing-game').html('Play Boxing Game');
	$('#boxing-game').addClass('stop').animate({opacity:'+=0'},600,function(){
		$(this).removeClass('stop').removeClass('playing');
	});
	$('#boxing-scorecard').slideUp('fast');
	$('#boxing-instructions').fadeOut('fast');
	return false;
}
$('#launch-boxing-game').toggle(function(){
	startBoxing();
},function(){
	stopBoxing();
	perspectiveShift('2d');
});


// ================
// = Note Storage =
// ================
function getStorage(type) { // Get Local Storage
	var storage = window[type + 'Storage'],
		delta = 0,
		li = document.createElement('li');

	delta = ((new Date()).getTime() - (new Date()).setTime(storage.getItem('timestamp'))) / 1000;

	if (!window[type + 'Storage']) return;

	$('#notes').html(storage.getItem('notes'));
	$('#ideas').html(storage.getItem('ideas'));
	$('#timestamp').html('Last updated: ' + delta + 's ago');
}
getStorage('local');

function saveStorage(){
	localStorage.setItem('notes', $('#notes').html());
	localStorage.setItem('ideas', $('#ideas').html());
	localStorage.setItem('timestamp', (new Date()).getTime());
	getStorage('local');
}
$('#save-changes').click(function(){ // Save to Local Storage
	saveStorage();
});
$('#undo-changes').click(function(){ // Reset to Local Storage
	getStorage('local');
});

$('#notes,#ideas').keypress(function(event) { // Handle cmd-s & ctrl-s for saving notes
	if(event.keyCode == '19' || event.keyCode == '115' && event.metaKey){
		event.preventDefault();
		saveStorage();
	}
});